class ImageKeyConverter(StringConverter):
 """
 Provides a type converter to convert data for an image key to and from another data type.

 

 ImageKeyConverter()
 """
 def CanConvertFrom(self,*__args):
  """
  CanConvertFrom(self: ImageKeyConverter,context: ITypeDescriptorContext,sourceType: Type) -> bool

  

   Returns whether this converter can convert an object of the given type to a string using the 

    specified context.

  

  

   context: An System.ComponentModel.ITypeDescriptorContext that provides a format context.

   sourceType: A System.Type that specifies the type you want to convert from.

   Returns: true to indicate the specified conversion can be performed; otherwise,false.
  """
  pass
 def ConvertFrom(self,*__args):
  """
  ConvertFrom(self: ImageKeyConverter,context: ITypeDescriptorContext,culture: CultureInfo,value: object) -> object

  

   Converts from the specified object to a string.

  

   context: An System.ComponentModel.ITypeDescriptorContext that provides a format context.

   culture: A System.Globalization.CultureInfo to provide locale information.

   value: The System.Object to convert.

   Returns: An System.Object that represents the converted value.
  """
  pass
 def ConvertTo(self,*__args):
  """
  ConvertTo(self: ImageKeyConverter,context: ITypeDescriptorContext,culture: CultureInfo,value: object,destinationType: Type) -> object

  

   Converts the given object to the specified type.

  

   context: An System.ComponentModel.ITypeDescriptorContext that provides a format context,which can be 

    used to extract additional information about the environment this type converter is being 

    invoked from. This parameter or properties of this parameter can be null.

  

   culture: A System.Globalization.CultureInfo that provides locale information.

   value: The object to convert,typically an image key.

   destinationType: The type to convert the object to.

   Returns: An System.Object that represents the converted value.
  """
  pass
 def GetStandardValues(self,context=None):
  """
  GetStandardValues(self: ImageKeyConverter,context: ITypeDescriptorContext) -> StandardValuesCollection

  

   Returns a collection of standard image keys for the image list associated with the specified 

    context.

  

  

   context: An System.ComponentModel.ITypeDescriptorContext that provides a format context,which can be 

    used to extract additional information about the environment this type converter is being 

    invoked from. This parameter or properties of this parameter can be null.

  

   Returns: A System.ComponentModel.TypeConverter.StandardValuesCollection that contains the standard set of 

    image key values.
  """
  pass
 def GetStandardValuesExclusive(self,context=None):
  """
  GetStandardValuesExclusive(self: ImageKeyConverter,context: ITypeDescriptorContext) -> bool

  

   Determines whether the list of standard values for the System.Windows.Forms.ImageKeyConverter is 

    exclusive (that is,whether it allows values other than those returned by 

    erload:System.Windows.Forms.ImageKeyConverter.GetStandardValues).

  

  

   context: An System.ComponentModel.ITypeDescriptorContext that provides a format context,which can be 

    used to extract additional information about the environment this type converter is being 

    invoked from. This parameter or properties of this parameter can be null.

  

   Returns: true to indicate the list does not allow additional values; otherwise,false. Always returns 

    true.
  """
  pass
 def GetStandardValuesSupported(self,context=None):
  """
  GetStandardValuesSupported(self: ImageKeyConverter,context: ITypeDescriptorContext) -> bool

  

   Determines whether this type converter supports a standard set of values that can be picked from 

    a list.

  

  

   context: An System.ComponentModel.ITypeDescriptorContext that provides a format context,which can be 

    used to extract additional information about the environment this type converter is being 

    invoked from. This parameter or properties of this parameter can be null.

  

   Returns: true to indicate a list of standard values is supported; otherwise,false. Always returns true.
  """
  pass
 IncludeNoneAsStandardValue=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether null is valid in the System.ComponentModel.TypeConverter.StandardValuesCollection collection.



"""





class CalendarModeChangedEventArgs(RoutedEventArgs):
 """
 Provides data for the System.Windows.Controls.Calendar.DisplayModeChanged event.

 

 CalendarModeChangedEventArgs(oldMode: CalendarMode,newMode: CalendarMode)
 """
 @staticmethod
 def __new__(self,oldMode,newMode):
  """ __new__(cls: type,oldMode: CalendarMode,newMode: CalendarMode) """
  pass
 NewMode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the new mode of the System.Windows.Controls.Calendar.



Get: NewMode(self: CalendarModeChangedEventArgs) -> CalendarMode



"""

 OldMode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the previous mode of the System.Windows.Controls.Calendar.



Get: OldMode(self: CalendarModeChangedEventArgs) -> CalendarMode



"""





class Application(object):
 """ Provides static methods and properties to manage an application,such as methods to start and stop an application,to process Windows messages,and properties to get information about an application. This class cannot be inherited. """
 @staticmethod
 def AddMessageFilter(value):
  """
  AddMessageFilter(value: IMessageFilter)

   Adds a message filter to monitor Windows messages as they are routed to their destinations.

  

   value: The implementation of the System.Windows.Forms.IMessageFilter interface you want to install.
  """
  pass
 @staticmethod
 def DoEvents():
  """
  DoEvents()

   Processes all Windows messages currently in the message queue.
  """
  pass
 @staticmethod
 def EnableVisualStyles():
  """
  EnableVisualStyles()

   Enables visual styles for the application.
  """
  pass
 @staticmethod
 def Exit(e=None):
  """
  Exit(e: CancelEventArgs)

   Informs all message pumps that they must terminate,and then closes all application windows 

    after the messages have been processed.

  

  

   e: Returns whether any System.Windows.Forms.Form within the application cancelled the exit.

  Exit()

   Informs all message pumps that they must terminate,and then closes all application windows 

    after the messages have been processed.
  """
  pass
 @staticmethod
 def ExitThread():
  """
  ExitThread()

   Exits the message loop on the current thread and closes all windows on the thread.
  """
  pass
 @staticmethod
 def FilterMessage(message):
  """
  FilterMessage(message: Message) -> (bool,Message)

  

   Runs any filters against a window message,and returns a copy of the modified message.

  

   message: The Windows event message to filter.

   Returns: True if the filters were processed; otherwise,false.
  """
  pass
 @staticmethod
 def OleRequired():
  """
  OleRequired() -> ApartmentState

  

   Initializes OLE on the current thread.

   Returns: One of the System.Threading.ApartmentState values.
  """
  pass
 @staticmethod
 def OnThreadException(t):
  """
  OnThreadException(t: Exception)

   Raises the System.Windows.Forms.Application.ThreadException event.

  

   t: An System.Exception that represents the exception that was thrown.
  """
  pass
 @staticmethod
 def RaiseIdle(e):
  """
  RaiseIdle(e: EventArgs)

   Raises the System.Windows.Forms.Application.Idle event in hosted scenarios.

  

   e: The System.EventArgs objects to pass to the System.Windows.Forms.Application.Idle event.
  """
  pass
 @staticmethod
 def RegisterMessageLoop(callback):
  """ RegisterMessageLoop(callback: MessageLoopCallback) """
  pass
 @staticmethod
 def RemoveMessageFilter(value):
  """
  RemoveMessageFilter(value: IMessageFilter)

   Removes a message filter from the message pump of the application.

  

   value: The implementation of the System.Windows.Forms.IMessageFilter to remove from the application.
  """
  pass
 @staticmethod
 def Restart():
  """
  Restart()

   Shuts down the application and starts a new instance immediately.
  """
  pass
 @staticmethod
 def Run(*__args):
  """
  Run(context: ApplicationContext)

   Begins running a standard application message loop on the current thread,with an 

    System.Windows.Forms.ApplicationContext.

  

  

   context: An System.Windows.Forms.ApplicationContext in which the application is run.

  Run(mainForm: Form)

   Begins running a standard application message loop on the current thread,and makes the 

    specified form visible.

  

  

   mainForm: A System.Windows.Forms.Form that represents the form to make visible.

  Run()

   Begins running a standard application message loop on the current thread,without a form.
  """
  pass
 @staticmethod
 def SetCompatibleTextRenderingDefault(defaultValue):
  """
  SetCompatibleTextRenderingDefault(defaultValue: bool)

   Sets the application-wide default for the UseCompatibleTextRendering property defined on certain 

    controls.

  

  

   defaultValue: The default value to use for new controls. If true,new controls that support 

    UseCompatibleTextRendering use the GDI+ based System.Drawing.Graphics class for text rendering; 

    if false,new controls use the GDI�based System.Windows.Forms.TextRenderer class.
  """
  pass
 @staticmethod
 def SetSuspendState(state,force,disableWakeEvent):
  """
  SetSuspendState(state: PowerState,force: bool,disableWakeEvent: bool) -> bool

  

   Suspends or hibernates the system,or requests that the system be suspended or hibernated.

  

   state: A System.Windows.Forms.PowerState indicating the power activity mode to which to transition.

   force: true to force the suspended mode immediately; false to cause Windows to send a suspend request 

    to every application.

  

   disableWakeEvent: true to disable restoring the system's power status to active on a wake event,false to enable 

    restoring the system's power status to active on a wake event.

  

   Returns: true if the system is being suspended,otherwise,false.
  """
  pass
 @staticmethod
 def SetUnhandledExceptionMode(mode,threadScope=None):
  """
  SetUnhandledExceptionMode(mode: UnhandledExceptionMode,threadScope: bool)

   Instructs the application how to respond to unhandled exceptions,optionally applying 

    thread-specific behavior.

  

  

   mode: An System.Windows.Forms.UnhandledExceptionMode value describing how the application should 

    behave if an exception is thrown without being caught.

  

   threadScope: true to set the thread exception mode; otherwise,false.

  SetUnhandledExceptionMode(mode: UnhandledExceptionMode)

   Instructs the application how to respond to unhandled exceptions.

  

   mode: An System.Windows.Forms.UnhandledExceptionMode value describing how the application should 

    behave if an exception is thrown without being caught.
  """
  pass
 @staticmethod
 def UnregisterMessageLoop():
  """
  UnregisterMessageLoop()

   Unregisters the message loop callback made with 

    System.Windows.Forms.Application.RegisterMessageLoop(System.Windows.Forms.Application.MessageLoop

    Callback).
  """
  pass
 AllowQuit=False
 ApplicationExit=None
 CommonAppDataPath='C:\\ProgramData\\IronPython Team\\IronPython\\IronPython 2.7.7 final 0'
 CompanyName='IronPython Team'
 CurrentCulture=None
 CurrentInputLanguage=None
 EnterThreadModal=None
 ExecutablePath='C:\\Program Files (x86)\\IronPython-2.7.7\\ipy.exe'
 Idle=None
 LeaveThreadModal=None
 LocalUserAppDataPath='C:\\Users\\gtalarico\\AppData\\Local\\IronPython Team\\IronPython\\IronPython 2.7.7 final 0'
 MessageLoop=False
 MessageLoopCallback=None
 OpenForms=None
 ProductName='IronPython'
 ProductVersion='IronPython 2.7.7 final 0'
 RenderWithVisualStyles=False
 SafeTopLevelCaptionFormat='{1} - {0} - {2}'
 StartupPath='C:\\Program Files (x86)\\IronPython-2.7.7'
 ThreadException=None
 ThreadExit=None
 UserAppDataPath='C:\\Users\\gtalarico\\AppData\\Roaming\\IronPython Team\\IronPython\\IronPython 2.7.7 final 0'
 UserAppDataRegistry=None
 UseWaitCursor=False
 VisualStyleState=None




class ItemContainerTemplateSelector(object):
 # no doc
 def SelectTemplate(self,item,parentItemsControl):
  """ SelectTemplate(self: ItemContainerTemplateSelector,item: object,parentItemsControl: ItemsControl) -> DataTemplate """
  pass



class QueryAccessibilityHelpEventArgs(EventArgs):
 """
 Provides data for the System.Windows.Forms.Control.QueryAccessibilityHelp event.

 

 QueryAccessibilityHelpEventArgs()

 QueryAccessibilityHelpEventArgs(helpNamespace: str,helpString: str,helpKeyword: str)
 """
 @staticmethod
 def __new__(self,helpNamespace=None,helpString=None,helpKeyword=None):
  """
  __new__(cls: type)

  __new__(cls: type,helpNamespace: str,helpString: str,helpKeyword: str)
  """
  pass
 HelpKeyword=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the Help keyword for the specified control.



Get: HelpKeyword(self: QueryAccessibilityHelpEventArgs) -> str



Set: HelpKeyword(self: QueryAccessibilityHelpEventArgs)=value

"""

 HelpNamespace=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value specifying the name of the Help file.



Get: HelpNamespace(self: QueryAccessibilityHelpEventArgs) -> str



Set: HelpNamespace(self: QueryAccessibilityHelpEventArgs)=value

"""

 HelpString=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the string defining what Help to get for the System.Windows.Forms.AccessibleObject.



Get: HelpString(self: QueryAccessibilityHelpEventArgs) -> str



Set: HelpString(self: QueryAccessibilityHelpEventArgs)=value

"""





class ErrorWrapper(object):
 """
 Wraps objects the marshaler should marshal as a VT_ERROR.

 

 ErrorWrapper(errorCode: int)

 ErrorWrapper(errorCode: object)

 ErrorWrapper(e: Exception)
 """
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type,errorCode: int)

  __new__(cls: type,errorCode: object)

  __new__(cls: type,e: Exception)
  """
  pass
 ErrorCode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the error code of the wrapper.



Get: ErrorCode(self: ErrorWrapper) -> int



"""





class BrowsableAttribute(Attribute,_Attribute):
 """
 Specifies whether a property or event should be displayed in a Properties window.

 

 BrowsableAttribute(browsable: bool)
 """
 def Equals(self,obj):
  """
  Equals(self: BrowsableAttribute,obj: object) -> bool

  

   Indicates whether this instance and a specified object are equal.

  

   obj: Another object to compare to.

   Returns: true if obj is equal to this instance; otherwise,false.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: BrowsableAttribute) -> int

  

   Returns the hash code for this instance.

   Returns: A 32-bit signed integer hash code.
  """
  pass
 def IsDefaultAttribute(self):
  """
  IsDefaultAttribute(self: BrowsableAttribute) -> bool

  

   Determines if this attribute is the default.

   Returns: true if the attribute is the default value for this attribute class; otherwise,false.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,browsable):
  """ __new__(cls: type,browsable: bool) """
  pass
 def __ne__(self,*args):
  pass
 Browsable=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether an object is browsable.



Get: Browsable(self: BrowsableAttribute) -> bool



"""


 Default=None
 No=None
 Yes=None




class MarshalAsAttribute(Attribute,_Attribute):
 """
 Indicates how to marshal the data between managed and unmanaged code.

 

 MarshalAsAttribute(unmanagedType: UnmanagedType)

 MarshalAsAttribute(unmanagedType: Int16)
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,unmanagedType):
  """
  __new__(cls: type,unmanagedType: UnmanagedType)

  __new__(cls: type,unmanagedType: Int16)
  """
  pass
 Value=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Runtime.InteropServices.UnmanagedType value the data is to be marshaled as.



Get: Value(self: MarshalAsAttribute) -> UnmanagedType



"""


 ArraySubType=None
 IidParameterIndex=None
 MarshalCookie=None
 MarshalType=None
 MarshalTypeRef=None
 SafeArraySubType=None
 SafeArrayUserDefinedSubType=None
 SizeConst=None
 SizeParamIndex=None




class AppDomainManager(MarshalByRefObject):
 """
 Provides a managed equivalent of an unmanaged host.

 

 AppDomainManager()
 """
 def CheckSecuritySettings(self,state):
  """
  CheckSecuritySettings(self: AppDomainManager,state: SecurityState) -> bool

  

   Indicates whether the specified operation is allowed in the application domain.

  

   state: A subclass of System.Security.SecurityState that identifies the operation whose security status 

    is requested.

  

   Returns: true if the host allows the operation specified by state to be performed in the application 

    domain; otherwise,false.
  """
  pass
 def CreateDomain(self,friendlyName,securityInfo,appDomainInfo):
  """
  CreateDomain(self: AppDomainManager,friendlyName: str,securityInfo: Evidence,appDomainInfo: AppDomainSetup) -> AppDomain

  

   Returns a new or existing application domain.

  

   friendlyName: The friendly name of the domain.

   securityInfo: An object that contains evidence mapped through the security policy to establish a top-of-stack 

    permission set.

  

   appDomainInfo: An object that contains application domain initialization information.

   Returns: A new or existing application domain.
  """
  pass
 def CreateDomainHelper(self,*args):
  """
  CreateDomainHelper(friendlyName: str,securityInfo: Evidence,appDomainInfo: AppDomainSetup) -> AppDomain

  

   Provides a helper method to create an application domain.

  

   friendlyName: The friendly name of the domain.

   securityInfo: An object that contains evidence mapped through the security policy to establish a top-of-stack 

    permission set.

  

   appDomainInfo: An object that contains application domain initialization information.

   Returns: A newly created application domain.
  """
  pass
 def InitializeNewDomain(self,appDomainInfo):
  """
  InitializeNewDomain(self: AppDomainManager,appDomainInfo: AppDomainSetup)

   Initializes the new application domain.

  

   appDomainInfo: An object that contains application domain initialization information.
  """
  pass
 ApplicationActivator=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the application activator that handles the activation of add-ins and manifest-based applications for the domain.



Get: ApplicationActivator(self: AppDomainManager) -> ApplicationActivator



"""

 EntryAssembly=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the entry assembly for an application.



Get: EntryAssembly(self: AppDomainManager) -> Assembly



"""

 HostExecutionContextManager=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the host execution context manager that manages the flow of the execution context.



Get: HostExecutionContextManager(self: AppDomainManager) -> HostExecutionContextManager



"""

 HostSecurityManager=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the host security manager that participates in security decisions for the application domain.



Get: HostSecurityManager(self: AppDomainManager) -> HostSecurityManager



"""

 InitializationFlags=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the initialization flags for custom application domain managers.



Get: InitializationFlags(self: AppDomainManager) -> AppDomainManagerInitializationOptions



Set: InitializationFlags(self: AppDomainManager)=value

"""





class UnmanagedMemoryStream(Stream,IDisposable):
 """
 Provides access to unmanaged blocks of memory from managed code.

 

 UnmanagedMemoryStream(buffer: SafeBuffer,offset: Int64,length: Int64)

 UnmanagedMemoryStream(buffer: SafeBuffer,offset: Int64,length: Int64,access: FileAccess)

 UnmanagedMemoryStream(pointer: Byte*,length: Int64)

 UnmanagedMemoryStream(pointer: Byte*,length: Int64,capacity: Int64,access: FileAccess)
 """
 def CreateWaitHandle(self,*args):
  """
  CreateWaitHandle(self: Stream) -> WaitHandle

  

   Allocates a System.Threading.WaitHandle object.

   Returns: A reference to the allocated WaitHandle.
  """
  pass
 def Dispose(self):
  """
  Dispose(self: UnmanagedMemoryStream,disposing: bool)

   Releases the unmanaged resources used by the System.IO.UnmanagedMemoryStream and optionally 

    releases the managed resources.

  

  

   disposing: true to release both managed and unmanaged resources; false to release only unmanaged resources.
  """
  pass
 def Flush(self):
  """
  Flush(self: UnmanagedMemoryStream)

   Overrides the System.IO.Stream.Flush method so that no action is performed.
  """
  pass
 def FlushAsync(self,cancellationToken=None):
  """ FlushAsync(self: UnmanagedMemoryStream,cancellationToken: CancellationToken) -> Task """
  pass
 def Initialize(self,*args):
  """
  Initialize(self: UnmanagedMemoryStream,buffer: SafeBuffer,offset: Int64,length: Int64,access: FileAccess)

   Initializes a new instance of the System.IO.UnmanagedMemoryStream class in a safe buffer with a 

    specified offset,length,and file access.

  

  

   buffer: The buffer to contain the unmanaged memory stream.

   offset: The byte position in the buffer at which to start the unmanaged memory stream.

   length: The length of the unmanaged memory stream.

   access: The mode of file access to the unmanaged memory stream.

  Initialize(self: UnmanagedMemoryStream,pointer: Byte*,length: Int64,capacity: Int64,access: FileAccess)

   Initializes a new instance of the System.IO.UnmanagedMemoryStream class by using a pointer to an 

    unmanaged memory location.

  

  

   pointer: A pointer to an unmanaged memory location.

   length: The length of the memory to use.

   capacity: The total amount of memory assigned to the stream.

   access: One of the System.IO.FileAccess values.
  """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 def ObjectInvariant(self,*args):
  """
  ObjectInvariant(self: Stream)

   Provides support for a System.Diagnostics.Contracts.Contract.
  """
  pass
 def Read(self,buffer,offset,count):
  """
  Read(self: UnmanagedMemoryStream,offset: int,count: int) -> (int,Array[Byte])

  

   Reads the specified number of bytes into the specified array.

  

   offset: The zero-based byte offset in buffer at which to begin storing the data read from the current 

    stream.

  

   count: The maximum number of bytes to read from the current stream.

   Returns: The total number of bytes read into the buffer. This can be less than the number of bytes 

    requested if that many bytes are not currently available,or zero (0) if the end of the stream 

    has been reached.
  """
  pass
 def ReadAsync(self,buffer,offset,count,cancellationToken=None):
  """ ReadAsync(self: UnmanagedMemoryStream,buffer: Array[Byte],offset: int,count: int,cancellationToken: CancellationToken) -> Task[int] """
  pass
 def ReadByte(self):
  """
  ReadByte(self: UnmanagedMemoryStream) -> int

  

   Reads a byte from a stream and advances the position within the stream by one byte,or returns 

    -1 if at the end of the stream.

  

   Returns: The unsigned byte cast to an System.Int32 object,or -1 if at the end of the stream.
  """
  pass
 def Seek(self,offset,loc):
  """
  Seek(self: UnmanagedMemoryStream,offset: Int64,loc: SeekOrigin) -> Int64

  

   Sets the current position of the current stream to the given value.

  

   offset: The point relative to origin to begin seeking from.

   loc: Specifies the beginning,the end,or the current position as a reference point for origin,using 

    a value of type System.IO.SeekOrigin.

  

   Returns: The new position in the stream.
  """
  pass
 def SetLength(self,value):
  """
  SetLength(self: UnmanagedMemoryStream,value: Int64)

   Sets the length of a stream to a specified value.

  

   value: The length of the stream.
  """
  pass
 def Write(self,buffer,offset,count):
  """
  Write(self: UnmanagedMemoryStream,buffer: Array[Byte],offset: int,count: int)

   Writes a block of bytes to the current stream using data from a buffer.

  

   buffer: The byte array from which to copy bytes to the current stream.

   offset: The offset in the buffer at which to begin copying bytes to the current stream.

   count: The number of bytes to write to the current stream.
  """
  pass
 def WriteAsync(self,buffer,offset,count,cancellationToken=None):
  """ WriteAsync(self: UnmanagedMemoryStream,buffer: Array[Byte],offset: int,count: int,cancellationToken: CancellationToken) -> Task """
  pass
 def WriteByte(self,value):
  """
  WriteByte(self: UnmanagedMemoryStream,value: Byte)

   Writes a byte to the current position in the file stream.

  

   value: A byte value written to the stream.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,buffer: SafeBuffer,offset: Int64,length: Int64)

  __new__(cls: type,buffer: SafeBuffer,offset: Int64,length: Int64,access: FileAccess)

  __new__(cls: type,pointer: Byte*,length: Int64)

  __new__(cls: type,pointer: Byte*,length: Int64,capacity: Int64,access: FileAccess)
  """
  pass
 CanRead=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether a stream supports reading.



Get: CanRead(self: UnmanagedMemoryStream) -> bool



"""

 CanSeek=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether a stream supports seeking.



Get: CanSeek(self: UnmanagedMemoryStream) -> bool



"""

 CanWrite=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether a stream supports writing.



Get: CanWrite(self: UnmanagedMemoryStream) -> bool



"""

 Capacity=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the stream length (size) or the total amount of memory assigned to a stream (capacity).



Get: Capacity(self: UnmanagedMemoryStream) -> Int64



"""

 Length=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the length of the data in a stream.



Get: Length(self: UnmanagedMemoryStream) -> Int64



"""

 Position=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the current position in a stream.



Get: Position(self: UnmanagedMemoryStream) -> Int64



Set: Position(self: UnmanagedMemoryStream)=value

"""

 PositionPointer=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a byte pointer to a stream based on the current position in the stream.



Get: PositionPointer(self: UnmanagedMemoryStream) -> Byte*



Set: PositionPointer(self: UnmanagedMemoryStream)=value

"""





class IChangeTracking:
 """ Defines the mechanism for querying the object for changes and resetting of the changed status. """
 def AcceptChanges(self):
  """
  AcceptChanges(self: IChangeTracking)

    """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 IsChanged=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the object's changed status.



Get: IsChanged(self: IChangeTracking) -> bool



"""





class LicenseException(SystemException,ISerializable,_Exception):
 """
 Represents the exception thrown when a component cannot be granted a license.

 

 LicenseException(type: Type)

 LicenseException(type: Type,instance: object)

 LicenseException(type: Type,instance: object,message: str)

 LicenseException(type: Type,instance: object,message: str,innerException: Exception)
 """
 def add_SerializeObjectState(self,*args):
  """ add_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def GetObjectData(self,info,context):
  """
  GetObjectData(self: LicenseException,info: SerializationInfo,context: StreamingContext)

   Sets the System.Runtime.Serialization.SerializationInfo with information about the exception.

  

   info: The System.Runtime.Serialization.SerializationInfo to be used for deserialization.

   context: The destination to be used for deserialization.
  """
  pass
 def remove_SerializeObjectState(self,*args):
  """ remove_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,type,instance=None,message=None,innerException=None):
  """
  __new__(cls: type,type: Type)

  __new__(cls: type,type: Type,instance: object)

  __new__(cls: type,type: Type,instance: object,message: str)

  __new__(cls: type,type: Type,instance: object,message: str,innerException: Exception)

  __new__(cls: type,info: SerializationInfo,context: StreamingContext)
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 LicensedType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the type of the component that was not granted a license.



Get: LicensedType(self: LicenseException) -> Type



"""





class DefaultParameterValueAttribute(Attribute,_Attribute):
 """
 Sets the default value of a parameter when called from a language that supports default parameters. This class cannot be inherited.

 

 DefaultParameterValueAttribute(value: object)
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,value):
  """ __new__(cls: type,value: object) """
  pass
 Value=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the default value of a parameter.



Get: Value(self: DefaultParameterValueAttribute) -> object



"""





# encoding: utf-8
# module System.IO.Ports calls itself Ports
# from System,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b77a5c561934e089
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes

class Handshake(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the control protocol used in establishing a serial port communication for a System.IO.Ports.SerialPort object.

 

 enum Handshake,values: None (0),RequestToSend (2),RequestToSendXOnXOff (3),XOnXOff (1)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 None=None
 RequestToSend=None
 RequestToSendXOnXOff=None
 value__=None
 XOnXOff=None


class Parity(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the parity bit for a System.IO.Ports.SerialPort object.

 

 enum Parity,values: Even (2),Mark (3),None (0),Odd (1),Space (4)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Even=None
 Mark=None
 None=None
 Odd=None
 Space=None
 value__=None


class SerialData(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the type of character that was received on the serial port of the System.IO.Ports.SerialPort object.

 

 enum SerialData,values: Chars (1),Eof (2)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Chars=None
 Eof=None
 value__=None


class SerialDataReceivedEventArgs(EventArgs):
 """ Provides data for the System.IO.Ports.SerialPort.DataReceived event. """
 EventType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the event type.



Get: EventType(self: SerialDataReceivedEventArgs) -> SerialData



"""



class SerialDataReceivedEventHandler(MulticastDelegate,ICloneable,ISerializable):
 """
 Represents the method that will handle the System.IO.Ports.SerialPort.DataReceived event of a System.IO.Ports.SerialPort object.

 

 SerialDataReceivedEventHandler(object: object,method: IntPtr)
 """
 def BeginInvoke(self,sender,e,callback,object):
  """ BeginInvoke(self: SerialDataReceivedEventHandler,sender: object,e: SerialDataReceivedEventArgs,callback: AsyncCallback,object: object) -> IAsyncResult """
  pass
 def CombineImpl(self,*args):
  """
  CombineImpl(self: MulticastDelegate,follow: Delegate) -> Delegate

  

   Combines this System.Delegate with the specified System.Delegate to form a new delegate.

  

   follow: The delegate to combine with this delegate.

   Returns: A delegate that is the new root of the System.MulticastDelegate invocation list.
  """
  pass
 def DynamicInvokeImpl(self,*args):
  """
  DynamicInvokeImpl(self: Delegate,args: Array[object]) -> object

  

   Dynamically invokes (late-bound) the method represented by the current delegate.

  

   args: An array of objects that are the arguments to pass to the method represented by the current 

    delegate.-or- null,if the method represented by the current delegate does not require 

    arguments.

  

   Returns: The object returned by the method represented by the delegate.
  """
  pass
 def EndInvoke(self,result):
  """ EndInvoke(self: SerialDataReceivedEventHandler,result: IAsyncResult) """
  pass
 def GetMethodImpl(self,*args):
  """
  GetMethodImpl(self: MulticastDelegate) -> MethodInfo

  

   Returns a static method represented by the current System.MulticastDelegate.

   Returns: A static method represented by the current System.MulticastDelegate.
  """
  pass
 def Invoke(self,sender,e):
  """ Invoke(self: SerialDataReceivedEventHandler,sender: object,e: SerialDataReceivedEventArgs) """
  pass
 def RemoveImpl(self,*args):
  """
  RemoveImpl(self: MulticastDelegate,value: Delegate) -> Delegate

  

   Removes an element from the invocation list of this System.MulticastDelegate that is equal to 

    the specified delegate.

  

  

   value: The delegate to search for in the invocation list.

   Returns: If value is found in the invocation list for this instance,then a new System.Delegate without 

    value in its invocation list; otherwise,this instance with its original invocation list.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,object,method):
  """ __new__(cls: type,object: object,method: IntPtr) """
  pass
 def __reduce_ex__(self,*args):
  pass

class SerialError(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies errors that occur on the System.IO.Ports.SerialPort object.

 

 enum SerialError,values: Frame (8),Overrun (2),RXOver (1),RXParity (4),TXFull (256)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Frame=None
 Overrun=None
 RXOver=None
 RXParity=None
 TXFull=None
 value__=None


class SerialErrorReceivedEventArgs(EventArgs):
 """ Prepares data for the System.IO.Ports.SerialPort.ErrorReceived event. """
 EventType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the event type.



Get: EventType(self: SerialErrorReceivedEventArgs) -> SerialError



"""



class SerialErrorReceivedEventHandler(MulticastDelegate,ICloneable,ISerializable):
 """
 Represents the method that will handle the System.IO.Ports.SerialPort.ErrorReceived event of a System.IO.Ports.SerialPort object.

 

 SerialErrorReceivedEventHandler(object: object,method: IntPtr)
 """
 def BeginInvoke(self,sender,e,callback,object):
  """ BeginInvoke(self: SerialErrorReceivedEventHandler,sender: object,e: SerialErrorReceivedEventArgs,callback: AsyncCallback,object: object) -> IAsyncResult """
  pass
 def CombineImpl(self,*args):
  """
  CombineImpl(self: MulticastDelegate,follow: Delegate) -> Delegate

  

   Combines this System.Delegate with the specified System.Delegate to form a new delegate.

  

   follow: The delegate to combine with this delegate.

   Returns: A delegate that is the new root of the System.MulticastDelegate invocation list.
  """
  pass
 def DynamicInvokeImpl(self,*args):
  """
  DynamicInvokeImpl(self: Delegate,args: Array[object]) -> object

  

   Dynamically invokes (late-bound) the method represented by the current delegate.

  

   args: An array of objects that are the arguments to pass to the method represented by the current 

    delegate.-or- null,if the method represented by the current delegate does not require 

    arguments.

  

   Returns: The object returned by the method represented by the delegate.
  """
  pass
 def EndInvoke(self,result):
  """ EndInvoke(self: SerialErrorReceivedEventHandler,result: IAsyncResult) """
  pass
 def GetMethodImpl(self,*args):
  """
  GetMethodImpl(self: MulticastDelegate) -> MethodInfo

  

   Returns a static method represented by the current System.MulticastDelegate.

   Returns: A static method represented by the current System.MulticastDelegate.
  """
  pass
 def Invoke(self,sender,e):
  """ Invoke(self: SerialErrorReceivedEventHandler,sender: object,e: SerialErrorReceivedEventArgs) """
  pass
 def RemoveImpl(self,*args):
  """
  RemoveImpl(self: MulticastDelegate,value: Delegate) -> Delegate

  

   Removes an element from the invocation list of this System.MulticastDelegate that is equal to 

    the specified delegate.

  

  

   value: The delegate to search for in the invocation list.

   Returns: If value is found in the invocation list for this instance,then a new System.Delegate without 

    value in its invocation list; otherwise,this instance with its original invocation list.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,object,method):
  """ __new__(cls: type,object: object,method: IntPtr) """
  pass
 def __reduce_ex__(self,*args):
  pass

class SerialPinChange(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the type of change that occurred on the System.IO.Ports.SerialPort object.

 

 enum SerialPinChange,values: Break (64),CDChanged (32),CtsChanged (8),DsrChanged (16),Ring (256)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Break=None
 CDChanged=None
 CtsChanged=None
 DsrChanged=None
 Ring=None
 value__=None


class SerialPinChangedEventArgs(EventArgs):
 """ Provides data for the System.IO.Ports.SerialPort.PinChanged event. """
 EventType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the event type.



Get: EventType(self: SerialPinChangedEventArgs) -> SerialPinChange



"""



class SerialPinChangedEventHandler(MulticastDelegate,ICloneable,ISerializable):
 """
 Represents the method that will handle the System.IO.Ports.SerialPort.PinChanged event of a System.IO.Ports.SerialPort object.

 

 SerialPinChangedEventHandler(object: object,method: IntPtr)
 """
 def BeginInvoke(self,sender,e,callback,object):
  """ BeginInvoke(self: SerialPinChangedEventHandler,sender: object,e: SerialPinChangedEventArgs,callback: AsyncCallback,object: object) -> IAsyncResult """
  pass
 def CombineImpl(self,*args):
  """
  CombineImpl(self: MulticastDelegate,follow: Delegate) -> Delegate

  

   Combines this System.Delegate with the specified System.Delegate to form a new delegate.

  

   follow: The delegate to combine with this delegate.

   Returns: A delegate that is the new root of the System.MulticastDelegate invocation list.
  """
  pass
 def DynamicInvokeImpl(self,*args):
  """
  DynamicInvokeImpl(self: Delegate,args: Array[object]) -> object

  

   Dynamically invokes (late-bound) the method represented by the current delegate.

  

   args: An array of objects that are the arguments to pass to the method represented by the current 

    delegate.-or- null,if the method represented by the current delegate does not require 

    arguments.

  

   Returns: The object returned by the method represented by the delegate.
  """
  pass
 def EndInvoke(self,result):
  """ EndInvoke(self: SerialPinChangedEventHandler,result: IAsyncResult) """
  pass
 def GetMethodImpl(self,*args):
  """
  GetMethodImpl(self: MulticastDelegate) -> MethodInfo

  

   Returns a static method represented by the current System.MulticastDelegate.

   Returns: A static method represented by the current System.MulticastDelegate.
  """
  pass
 def Invoke(self,sender,e):
  """ Invoke(self: SerialPinChangedEventHandler,sender: object,e: SerialPinChangedEventArgs) """
  pass
 def RemoveImpl(self,*args):
  """
  RemoveImpl(self: MulticastDelegate,value: Delegate) -> Delegate

  

   Removes an element from the invocation list of this System.MulticastDelegate that is equal to 

    the specified delegate.

  

  

   value: The delegate to search for in the invocation list.

   Returns: If value is found in the invocation list for this instance,then a new System.Delegate without 

    value in its invocation list; otherwise,this instance with its original invocation list.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,object,method):
  """ __new__(cls: type,object: object,method: IntPtr) """
  pass
 def __reduce_ex__(self,*args):
  pass

class SerialPort(Component,IComponent,IDisposable):
 """
 Represents a serial port resource.

 

 SerialPort(container: IContainer)

 SerialPort()

 SerialPort(portName: str)

 SerialPort(portName: str,baudRate: int)

 SerialPort(portName: str,baudRate: int,parity: Parity)

 SerialPort(portName: str,baudRate: int,parity: Parity,dataBits: int)

 SerialPort(portName: str,baudRate: int,parity: Parity,dataBits: int,stopBits: StopBits)
 """
 def Close(self):
  """
  Close(self: SerialPort)

   Closes the port connection,sets the System.IO.Ports.SerialPort.IsOpen property to false,and 

    disposes of the internal System.IO.Stream object.
  """
  pass
 def DiscardInBuffer(self):
  """
  DiscardInBuffer(self: SerialPort)

   Discards data from the serial driver's receive buffer.
  """
  pass
 def DiscardOutBuffer(self):
  """
  DiscardOutBuffer(self: SerialPort)

   Discards data from the serial driver's transmit buffer.
  """
  pass
 def Dispose(self):
  """
  Dispose(self: SerialPort,disposing: bool)

   Releases the unmanaged resources used by the System.IO.Ports.SerialPort and optionally releases 

    the managed resources.

  

  

   disposing: true to release both managed and unmanaged resources; false to release only unmanaged resources.
  """
  pass
 @staticmethod
 def GetPortNames():
  """
  GetPortNames() -> Array[str]

  

   Gets an array of serial port names for the current computer.

   Returns: An array of serial port names for the current computer.
  """
  pass
 def GetService(self,*args):
  """
  GetService(self: Component,service: Type) -> object

  

   Returns an object that represents a service provided by the System.ComponentModel.Component or 

    by its System.ComponentModel.Container.

  

  

   service: A service provided by the System.ComponentModel.Component.

   Returns: An System.Object that represents a service provided by the System.ComponentModel.Component,or 

    null if the System.ComponentModel.Component does not provide the specified service.
  """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 def Open(self):
  """
  Open(self: SerialPort)

   Opens a new serial port connection.
  """
  pass
 def Read(self,buffer,offset,count):
  """
  Read(self: SerialPort,buffer: Array[Char],offset: int,count: int) -> int

  

   Reads a number of characters from the System.IO.Ports.SerialPort input buffer and writes them 

    into an array of characters at a given offset.

  

  

   buffer: The character array to write the input to.

   offset: The offset in the buffer array to begin writing.

   count: The number of characters to read.

   Returns: The number of characters read.

  Read(self: SerialPort,buffer: Array[Byte],offset: int,count: int) -> int

  

   Reads a number of bytes from the System.IO.Ports.SerialPort input buffer and writes those bytes 

    into a byte array at the specified offset.

  

  

   buffer: The byte array to write the input to.

   offset: The offset in the buffer array to begin writing.

   count: The number of bytes to read.

   Returns: The number of bytes read.
  """
  pass
 def ReadByte(self):
  """
  ReadByte(self: SerialPort) -> int

  

   Synchronously reads one byte from the System.IO.Ports.SerialPort input buffer.

   Returns: The byte,cast to an System.Int32,or -1 if the end of the stream has been read.
  """
  pass
 def ReadChar(self):
  """
  ReadChar(self: SerialPort) -> int

  

   Synchronously reads one character from the System.IO.Ports.SerialPort input buffer.

   Returns: The character that was read.
  """
  pass
 def ReadExisting(self):
  """
  ReadExisting(self: SerialPort) -> str

  

   Reads all immediately available bytes,based on the encoding,in both the stream and the input 

    buffer of the System.IO.Ports.SerialPort object.

  

   Returns: The contents of the stream and the input buffer of the System.IO.Ports.SerialPort object.
  """
  pass
 def ReadLine(self):
  """
  ReadLine(self: SerialPort) -> str

  

   Reads up to the System.IO.Ports.SerialPort.NewLine value in the input buffer.

   Returns: The contents of the input buffer up to the first occurrence of a 

    System.IO.Ports.SerialPort.NewLine value.
  """
  pass
 def ReadTo(self,value):
  """
  ReadTo(self: SerialPort,value: str) -> str

  

   Reads a string up to the specified value in the input buffer.

  

   value: A value that indicates where the read operation stops.

   Returns: The contents of the input buffer up to the specified value.
  """
  pass
 def Write(self,*__args):
  """
  Write(self: SerialPort,buffer: Array[Byte],offset: int,count: int)

   Writes a specified number of bytes to the serial port using data from a buffer.

  

   buffer: The byte array that contains the data to write to the port.

   offset: The zero-based byte offset in the buffer parameter at which to begin copying bytes to the port.

   count: The number of bytes to write.

  Write(self: SerialPort,buffer: Array[Char],offset: int,count: int)

   Writes a specified number of characters to the serial port using data from a buffer.

  

   buffer: The character array that contains the data to write to the port.

   offset: The zero-based byte offset in the buffer parameter at which to begin copying bytes to the port.

   count: The number of characters to write.

  Write(self: SerialPort,text: str)

   Writes the specified string to the serial port.

  

   text: The string for output.
  """
  pass
 def WriteLine(self,text):
  """
  WriteLine(self: SerialPort,text: str)

   Writes the specified string and the System.IO.Ports.SerialPort.NewLine value to the output 

    buffer.

  

  

   text: The string to write to the output buffer.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type,container: IContainer)

  __new__(cls: type)

  __new__(cls: type,portName: str)

  __new__(cls: type,portName: str,baudRate: int)

  __new__(cls: type,portName: str,baudRate: int,parity: Parity)

  __new__(cls: type,portName: str,baudRate: int,parity: Parity,dataBits: int)

  __new__(cls: type,portName: str,baudRate: int,parity: Parity,dataBits: int,stopBits: StopBits)
  """
  pass
 def __str__(self,*args):
  pass
 BaseStream=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the underlying System.IO.Stream object for a System.IO.Ports.SerialPort object.



Get: BaseStream(self: SerialPort) -> Stream



"""

 BaudRate=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the serial baud rate.



Get: BaudRate(self: SerialPort) -> int



Set: BaudRate(self: SerialPort)=value

"""

 BreakState=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the break signal state.



Get: BreakState(self: SerialPort) -> bool



Set: BreakState(self: SerialPort)=value

"""

 BytesToRead=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the number of bytes of data in the receive buffer.



Get: BytesToRead(self: SerialPort) -> int



"""

 BytesToWrite=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the number of bytes of data in the send buffer.



Get: BytesToWrite(self: SerialPort) -> int



"""

 CanRaiseEvents=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the component can raise an event.



"""

 CDHolding=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the state of the Carrier Detect line for the port.



Get: CDHolding(self: SerialPort) -> bool



"""

 CtsHolding=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the state of the Clear-to-Send line.



Get: CtsHolding(self: SerialPort) -> bool



"""

 DataBits=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the standard length of data bits per byte.



Get: DataBits(self: SerialPort) -> int



Set: DataBits(self: SerialPort)=value

"""

 DesignMode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether the System.ComponentModel.Component is currently in design mode.



"""

 DiscardNull=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether null bytes are ignored when transmitted between the port and the receive buffer.



Get: DiscardNull(self: SerialPort) -> bool



Set: DiscardNull(self: SerialPort)=value

"""

 DsrHolding=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the state of the Data Set Ready (DSR) signal.



Get: DsrHolding(self: SerialPort) -> bool



"""

 DtrEnable=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that enables the Data Terminal Ready (DTR) signal during serial communication.



Get: DtrEnable(self: SerialPort) -> bool



Set: DtrEnable(self: SerialPort)=value

"""

 Encoding=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the byte encoding for pre- and post-transmission conversion of text.



Get: Encoding(self: SerialPort) -> Encoding



Set: Encoding(self: SerialPort)=value

"""

 Events=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the list of event handlers that are attached to this System.ComponentModel.Component.



"""

 Handshake=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the handshaking protocol for serial port transmission of data.



Get: Handshake(self: SerialPort) -> Handshake



Set: Handshake(self: SerialPort)=value

"""

 IsOpen=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating the open or closed status of the System.IO.Ports.SerialPort object.



Get: IsOpen(self: SerialPort) -> bool



"""

 NewLine=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the value used to interpret the end of a call to the System.IO.Ports.SerialPort.ReadLine and System.IO.Ports.SerialPort.WriteLine(System.String) methods.



Get: NewLine(self: SerialPort) -> str



Set: NewLine(self: SerialPort)=value

"""

 Parity=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the parity-checking protocol.



Get: Parity(self: SerialPort) -> Parity



Set: Parity(self: SerialPort)=value

"""

 ParityReplace=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the byte that replaces invalid bytes in a data stream when a parity error occurs.



Get: ParityReplace(self: SerialPort) -> Byte



Set: ParityReplace(self: SerialPort)=value

"""

 PortName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the port for communications,including but not limited to all available COM ports.



Get: PortName(self: SerialPort) -> str



Set: PortName(self: SerialPort)=value

"""

 ReadBufferSize=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the size of the System.IO.Ports.SerialPort input buffer.



Get: ReadBufferSize(self: SerialPort) -> int



Set: ReadBufferSize(self: SerialPort)=value

"""

 ReadTimeout=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the number of milliseconds before a time-out occurs when a read operation does not finish.



Get: ReadTimeout(self: SerialPort) -> int



Set: ReadTimeout(self: SerialPort)=value

"""

 ReceivedBytesThreshold=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the number of bytes in the internal input buffer before a System.IO.Ports.SerialPort.DataReceived event occurs.



Get: ReceivedBytesThreshold(self: SerialPort) -> int



Set: ReceivedBytesThreshold(self: SerialPort)=value

"""

 RtsEnable=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the Request to Send (RTS) signal is enabled during serial communication.



Get: RtsEnable(self: SerialPort) -> bool



Set: RtsEnable(self: SerialPort)=value

"""

 StopBits=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the standard number of stopbits per byte.



Get: StopBits(self: SerialPort) -> StopBits



Set: StopBits(self: SerialPort)=value

"""

 WriteBufferSize=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the size of the serial port output buffer.



Get: WriteBufferSize(self: SerialPort) -> int



Set: WriteBufferSize(self: SerialPort)=value

"""

 WriteTimeout=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the number of milliseconds before a time-out occurs when a write operation does not finish.



Get: WriteTimeout(self: SerialPort) -> int



Set: WriteTimeout(self: SerialPort)=value

"""


 DataReceived=None
 ErrorReceived=None
 InfiniteTimeout=-1
 PinChanged=None


class StopBits(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the number of stop bits used on the System.IO.Ports.SerialPort object.

 

 enum StopBits,values: None (0),One (1),OnePointFive (3),Two (2)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 None=None
 One=None
 OnePointFive=None
 Two=None
 value__=None





class StringFormatFlags(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the display and layout information for text strings.

 

 enum (flags) StringFormatFlags,values: DirectionRightToLeft (1),DirectionVertical (2),DisplayFormatControl (32),FitBlackBox (4),LineLimit (8192),MeasureTrailingSpaces (2048),NoClip (16384),NoFontFallback (1024),NoWrap (4096)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 DirectionRightToLeft=None
 DirectionVertical=None
 DisplayFormatControl=None
 FitBlackBox=None
 LineLimit=None
 MeasureTrailingSpaces=None
 NoClip=None
 NoFontFallback=None
 NoWrap=None
 value__=None




# encoding: utf-8
# module System.ComponentModel calls itself ComponentModel
# from System,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b77a5c561934e089
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes
from __init___parts.AddingNewEventArgs import AddingNewEventArgs
from __init___parts.AddingNewEventHandler import AddingNewEventHandler
from __init___parts.AmbientValueAttribute import AmbientValueAttribute
from __init___parts.TypeConverter import TypeConverter
from __init___parts.CollectionConverter import CollectionConverter
from __init___parts.ArrayConverter import ArrayConverter
from __init___parts.AsyncCompletedEventArgs import AsyncCompletedEventArgs
from __init___parts.AsyncCompletedEventHandler import AsyncCompletedEventHandler
from __init___parts.AsyncOperation import AsyncOperation
from __init___parts.AsyncOperationManager import AsyncOperationManager
from __init___parts.AttributeCollection import AttributeCollection
from __init___parts.AttributeProviderAttribute import AttributeProviderAttribute
from __init___parts.Component import Component
from __init___parts.BackgroundWorker import BackgroundWorker
from __init___parts.BaseNumberConverter import BaseNumberConverter
from __init___parts.BindableAttribute import BindableAttribute
from __init___parts.BindableSupport import BindableSupport
from __init___parts.BindingDirection import BindingDirection
from __init___parts.IBindingList import IBindingList
from __init___parts.ICancelAddNew import ICancelAddNew
from __init___parts.IRaiseItemChangedEvents import IRaiseItemChangedEvents
from __init___parts.BindingList import BindingList
from __init___parts.BooleanConverter import BooleanConverter
from __init___parts.BrowsableAttribute import BrowsableAttribute
from __init___parts.ByteConverter import ByteConverter
from __init___parts.CancelEventArgs import CancelEventArgs
from __init___parts.CancelEventHandler import CancelEventHandler
from __init___parts.CategoryAttribute import CategoryAttribute
from __init___parts.CharConverter import CharConverter
from __init___parts.CollectionChangeAction import CollectionChangeAction
from __init___parts.CollectionChangeEventArgs import CollectionChangeEventArgs
from __init___parts.CollectionChangeEventHandler import CollectionChangeEventHandler
from __init___parts.ComplexBindingPropertiesAttribute import ComplexBindingPropertiesAttribute
from __init___parts.ComponentCollection import ComponentCollection
from __init___parts.ReferenceConverter import ReferenceConverter
from __init___parts.ComponentConverter import ComponentConverter
from __init___parts.ComponentEditor import ComponentEditor
from __init___parts.ComponentResourceManager import ComponentResourceManager
from __init___parts.Container import Container
from __init___parts.ContainerFilterService import ContainerFilterService
from __init___parts.CultureInfoConverter import CultureInfoConverter
from __init___parts.CustomTypeDescriptor import CustomTypeDescriptor
from __init___parts.DataErrorsChangedEventArgs import DataErrorsChangedEventArgs
from __init___parts.DataObjectAttribute import DataObjectAttribute
from __init___parts.DataObjectFieldAttribute import DataObjectFieldAttribute
from __init___parts.DataObjectMethodAttribute import DataObjectMethodAttribute
from __init___parts.DataObjectMethodType import DataObjectMethodType
from __init___parts.DateTimeConverter import DateTimeConverter
from __init___parts.DateTimeOffsetConverter import DateTimeOffsetConverter
from __init___parts.DecimalConverter import DecimalConverter
from __init___parts.DefaultBindingPropertyAttribute import DefaultBindingPropertyAttribute
from __init___parts.DefaultEventAttribute import DefaultEventAttribute
from __init___parts.DefaultPropertyAttribute import DefaultPropertyAttribute
from __init___parts.DefaultValueAttribute import DefaultValueAttribute
from __init___parts.DescriptionAttribute import DescriptionAttribute
from __init___parts.DesignerAttribute import DesignerAttribute
from __init___parts.DesignerCategoryAttribute import DesignerCategoryAttribute
from __init___parts.DesignerSerializationVisibility import DesignerSerializationVisibility
from __init___parts.DesignerSerializationVisibilityAttribute import DesignerSerializationVisibilityAttribute
from __init___parts.DesignOnlyAttribute import DesignOnlyAttribute
from __init___parts.DesignTimeVisibleAttribute import DesignTimeVisibleAttribute
from __init___parts.DisplayNameAttribute import DisplayNameAttribute
from __init___parts.DoubleConverter import DoubleConverter
from __init___parts.DoWorkEventArgs import DoWorkEventArgs
from __init___parts.DoWorkEventHandler import DoWorkEventHandler
from __init___parts.EditorAttribute import EditorAttribute
from __init___parts.EditorBrowsableAttribute import EditorBrowsableAttribute
from __init___parts.EditorBrowsableState import EditorBrowsableState
from __init___parts.EnumConverter import EnumConverter
from __init___parts.MemberDescriptor import MemberDescriptor
from __init___parts.EventDescriptor import EventDescriptor
from __init___parts.EventDescriptorCollection import EventDescriptorCollection
from __init___parts.EventHandlerList import EventHandlerList
from __init___parts.ExpandableObjectConverter import ExpandableObjectConverter
from __init___parts.ExtenderProvidedPropertyAttribute import ExtenderProvidedPropertyAttribute
from __init___parts.GuidConverter import GuidConverter
from __init___parts.HandledEventArgs import HandledEventArgs
from __init___parts.HandledEventHandler import HandledEventHandler
from __init___parts.IBindingListView import IBindingListView
from __init___parts.IChangeTracking import IChangeTracking
from __init___parts.IComNativeDescriptorHandler import IComNativeDescriptorHandler
from __init___parts.IComponent import IComponent
from __init___parts.IContainer import IContainer
from __init___parts.ICustomTypeDescriptor import ICustomTypeDescriptor
from __init___parts.IDataErrorInfo import IDataErrorInfo
from __init___parts.IEditableObject import IEditableObject
from __init___parts.IExtenderProvider import IExtenderProvider
from __init___parts.IIntellisenseBuilder import IIntellisenseBuilder
from __init___parts.IListSource import IListSource
from __init___parts.ImmutableObjectAttribute import ImmutableObjectAttribute
from __init___parts.INestedContainer import INestedContainer
from __init___parts.ISite import ISite
from __init___parts.INestedSite import INestedSite
from __init___parts.InheritanceAttribute import InheritanceAttribute
from __init___parts.InheritanceLevel import InheritanceLevel
from __init___parts.InitializationEventAttribute import InitializationEventAttribute
from __init___parts.INotifyDataErrorInfo import INotifyDataErrorInfo
from __init___parts.INotifyPropertyChanged import INotifyPropertyChanged
from __init___parts.INotifyPropertyChanging import INotifyPropertyChanging
from __init___parts.InstallerTypeAttribute import InstallerTypeAttribute
from __init___parts.InstanceCreationEditor import InstanceCreationEditor
from __init___parts.Int16Converter import Int16Converter
from __init___parts.Int32Converter import Int32Converter
from __init___parts.Int64Converter import Int64Converter
from __init___parts.InvalidAsynchronousStateException import InvalidAsynchronousStateException
from __init___parts.InvalidEnumArgumentException import InvalidEnumArgumentException
from __init___parts.IRevertibleChangeTracking import IRevertibleChangeTracking
from __init___parts.ISupportInitialize import ISupportInitialize
from __init___parts.ISupportInitializeNotification import ISupportInitializeNotification
from __init___parts.ISynchronizeInvoke import ISynchronizeInvoke
from __init___parts.ITypeDescriptorContext import ITypeDescriptorContext
from __init___parts.ITypedList import ITypedList
from __init___parts.License import License
from __init___parts.LicenseContext import LicenseContext
from __init___parts.LicenseException import LicenseException
from __init___parts.LicenseManager import LicenseManager
from __init___parts.LicenseProvider import LicenseProvider
from __init___parts.LicenseProviderAttribute import LicenseProviderAttribute
from __init___parts.LicenseUsageMode import LicenseUsageMode
from __init___parts.LicFileLicenseProvider import LicFileLicenseProvider
from __init___parts.ListBindableAttribute import ListBindableAttribute
from __init___parts.ListChangedEventArgs import ListChangedEventArgs
from __init___parts.ListChangedEventHandler import ListChangedEventHandler
from __init___parts.ListChangedType import ListChangedType
from __init___parts.ListSortDescription import ListSortDescription
from __init___parts.ListSortDescriptionCollection import ListSortDescriptionCollection
from __init___parts.ListSortDirection import ListSortDirection
from __init___parts.LocalizableAttribute import LocalizableAttribute
from __init___parts.LookupBindingPropertiesAttribute import LookupBindingPropertiesAttribute
from __init___parts.MarshalByValueComponent import MarshalByValueComponent
from __init___parts.MaskedTextProvider import MaskedTextProvider
from __init___parts.MaskedTextResultHint import MaskedTextResultHint
from __init___parts.MergablePropertyAttribute import MergablePropertyAttribute
from __init___parts.MultilineStringConverter import MultilineStringConverter
from __init___parts.NestedContainer import NestedContainer
from __init___parts.NotifyParentPropertyAttribute import NotifyParentPropertyAttribute
from __init___parts.NullableConverter import NullableConverter
from __init___parts.ParenthesizePropertyNameAttribute import ParenthesizePropertyNameAttribute
from __init___parts.PasswordPropertyTextAttribute import PasswordPropertyTextAttribute
from __init___parts.ProgressChangedEventArgs import ProgressChangedEventArgs
from __init___parts.ProgressChangedEventHandler import ProgressChangedEventHandler
from __init___parts.PropertyChangedEventArgs import PropertyChangedEventArgs
from __init___parts.PropertyChangedEventHandler import PropertyChangedEventHandler
from __init___parts.PropertyChangingEventArgs import PropertyChangingEventArgs
from __init___parts.PropertyChangingEventHandler import PropertyChangingEventHandler
from __init___parts.PropertyDescriptor import PropertyDescriptor
from __init___parts.PropertyDescriptorCollection import PropertyDescriptorCollection
from __init___parts.PropertyTabAttribute import PropertyTabAttribute
from __init___parts.PropertyTabScope import PropertyTabScope
from __init___parts.ProvidePropertyAttribute import ProvidePropertyAttribute
from __init___parts.ReadOnlyAttribute import ReadOnlyAttribute
from __init___parts.RecommendedAsConfigurableAttribute import RecommendedAsConfigurableAttribute
from __init___parts.RefreshEventArgs import RefreshEventArgs
from __init___parts.RefreshEventHandler import RefreshEventHandler
from __init___parts.RefreshProperties import RefreshProperties
from __init___parts.RefreshPropertiesAttribute import RefreshPropertiesAttribute
from __init___parts.RunInstallerAttribute import RunInstallerAttribute
from __init___parts.RunWorkerCompletedEventArgs import RunWorkerCompletedEventArgs
from __init___parts.RunWorkerCompletedEventHandler import RunWorkerCompletedEventHandler
from __init___parts.SByteConverter import SByteConverter
from __init___parts.SettingsBindableAttribute import SettingsBindableAttribute
from __init___parts.SingleConverter import SingleConverter
from __init___parts.StringConverter import StringConverter
from __init___parts.SyntaxCheck import SyntaxCheck
from __init___parts.TimeSpanConverter import TimeSpanConverter
from __init___parts.ToolboxItemAttribute import ToolboxItemAttribute
from __init___parts.ToolboxItemFilterAttribute import ToolboxItemFilterAttribute
from __init___parts.ToolboxItemFilterType import ToolboxItemFilterType
from __init___parts.TypeConverterAttribute import TypeConverterAttribute
from __init___parts.TypeDescriptionProvider import TypeDescriptionProvider
from __init___parts.TypeDescriptionProviderAttribute import TypeDescriptionProviderAttribute
from __init___parts.TypeDescriptor import TypeDescriptor
from __init___parts.TypeListConverter import TypeListConverter
from __init___parts.UInt16Converter import UInt16Converter
from __init___parts.UInt32Converter import UInt32Converter
from __init___parts.UInt64Converter import UInt64Converter
from __init___parts.WarningException import WarningException
from __init___parts.Win32Exception import Win32Exception



class PerformanceCounterPermissionEntryCollection(CollectionBase,IList,ICollection,IEnumerable):
 """ Contains a strongly typed collection of System.Diagnostics.PerformanceCounterPermissionEntry objects. """
 def Add(self,value):
  """
  Add(self: PerformanceCounterPermissionEntryCollection,value: PerformanceCounterPermissionEntry) -> int

  

   Adds a specified System.Diagnostics.PerformanceCounterPermissionEntry to this collection.

  

   value: The System.Diagnostics.PerformanceCounterPermissionEntry object to add.

   Returns: The zero-based index of the added System.Diagnostics.PerformanceCounterPermissionEntry object.
  """
  pass
 def AddRange(self,value):
  """
  AddRange(self: PerformanceCounterPermissionEntryCollection,value: PerformanceCounterPermissionEntryCollection)

   Appends a set of specified permission entries to this collection.

  

   value: A System.Diagnostics.PerformanceCounterPermissionEntryCollection that contains the permission 

    entries to add.

  

  AddRange(self: PerformanceCounterPermissionEntryCollection,value: Array[PerformanceCounterPermissionEntry])

   Appends a set of specified permission entries to this collection.

  

   value: An array of type System.Diagnostics.PerformanceCounterPermissionEntry objects that contains the 

    permission entries to add.
  """
  pass
 def Contains(self,value):
  """
  Contains(self: PerformanceCounterPermissionEntryCollection,value: PerformanceCounterPermissionEntry) -> bool

  

   Determines whether this collection contains a specified 

    System.Diagnostics.PerformanceCounterPermissionEntry object.

  

  

   value: The System.Diagnostics.PerformanceCounterPermissionEntry object to find.

   Returns: true if the specified System.Diagnostics.PerformanceCounterPermissionEntry object belongs to 

    this collection; otherwise,false.
  """
  pass
 def CopyTo(self,array,index):
  """
  CopyTo(self: PerformanceCounterPermissionEntryCollection,array: Array[PerformanceCounterPermissionEntry],index: int)

   Copies the permission entries from this collection to an array,starting at a particular index 

    of the array.

  

  

   array: An array of type System.Diagnostics.PerformanceCounterPermissionEntry that receives this 

    collection's permission entries.

  

   index: The zero-based index at which to begin copying the permission entries.
  """
  pass
 def IndexOf(self,value):
  """
  IndexOf(self: PerformanceCounterPermissionEntryCollection,value: PerformanceCounterPermissionEntry) -> int

  

   Determines the index of a specified permission entry in this collection.

  

   value: The permission entry for which to search.

   Returns: The zero-based index of the specified permission entry,or -1 if the permission entry was not 

    found in the collection.
  """
  pass
 def Insert(self,index,value):
  """
  Insert(self: PerformanceCounterPermissionEntryCollection,index: int,value: PerformanceCounterPermissionEntry)

   Inserts a permission entry into this collection at a specified index.

  

   index: The zero-based index of the collection at which to insert the permission entry.

   value: The permission entry to insert into this collection.
  """
  pass
 def OnClear(self,*args):
  """
  OnClear(self: PerformanceCounterPermissionEntryCollection)

   Performs additional custom processes after clearing the contents of the collection.
  """
  pass
 def OnClearComplete(self,*args):
  """
  OnClearComplete(self: CollectionBase)

   Performs additional custom processes after clearing the contents of the 

    System.Collections.CollectionBase instance.
  """
  pass
 def OnInsert(self,*args):
  """
  OnInsert(self: PerformanceCounterPermissionEntryCollection,index: int,value: object)

   Performs additional custom processes before a new permission entry is inserted into the 

    collection.

  

  

   index: The zero-based index at which to insert value.

   value: The new value of the permission entry at index.
  """
  pass
 def OnInsertComplete(self,*args):
  """
  OnInsertComplete(self: CollectionBase,index: int,value: object)

   Performs additional custom processes after inserting a new element into the 

    System.Collections.CollectionBase instance.

  

  

   index: The zero-based index at which to insert value.

   value: The new value of the element at index.
  """
  pass
 def OnRemove(self,*args):
  """
  OnRemove(self: PerformanceCounterPermissionEntryCollection,index: int,value: object)

   Performs additional custom processes when removing a new permission entry from the collection.

  

   index: The zero-based index at which value can be found.

   value: The permission entry to remove from index.
  """
  pass
 def OnRemoveComplete(self,*args):
  """
  OnRemoveComplete(self: CollectionBase,index: int,value: object)

   Performs additional custom processes after removing an element from the 

    System.Collections.CollectionBase instance.

  

  

   index: The zero-based index at which value can be found.

   value: The value of the element to remove from index.
  """
  pass
 def OnSet(self,*args):
  """
  OnSet(self: PerformanceCounterPermissionEntryCollection,index: int,oldValue: object,newValue: object)

   Performs additional custom processes before setting a value in the collection.

  

   index: The zero-based index at which oldValue can be found.

   oldValue: The value to replace with newValue.

   newValue: The new value of the permission entry at index.
  """
  pass
 def OnSetComplete(self,*args):
  """
  OnSetComplete(self: CollectionBase,index: int,oldValue: object,newValue: object)

   Performs additional custom processes after setting a value in the 

    System.Collections.CollectionBase instance.

  

  

   index: The zero-based index at which oldValue can be found.

   oldValue: The value to replace with newValue.

   newValue: The new value of the element at index.
  """
  pass
 def OnValidate(self,*args):
  """
  OnValidate(self: CollectionBase,value: object)

   Performs additional custom processes when validating a value.

  

   value: The object to validate.
  """
  pass
 def Remove(self,value):
  """
  Remove(self: PerformanceCounterPermissionEntryCollection,value: PerformanceCounterPermissionEntry)

   Removes a specified permission entry from this collection.

  

   value: The permission entry to remove.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]= """
  pass
 InnerList=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets an System.Collections.ArrayList containing the list of elements in the System.Collections.CollectionBase instance.



"""

 List=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets an System.Collections.IList containing the list of elements in the System.Collections.CollectionBase instance.



"""





class FeatureSupport(object,IFeatureSupport):
 """ Provides static methods for retrieving feature information from the current system. """
 @staticmethod
 def GetVersionPresent(*__args):
  """
  GetVersionPresent(self: FeatureSupport,feature: object) -> Version

  

   When overridden in a derived class,gets the version of the specified feature that is available 

    on the system.

  

  

   feature: The feature whose version is requested.

   Returns: A System.Version representing the version number of the specified feature available on the 

    system; or null if the feature is not installed.

  

  GetVersionPresent(featureClassName: str,featureConstName: str) -> Version

  

   Gets the version of the specified feature that is available on the system.

  

   featureClassName: The fully qualified name of the class to query for information about the specified feature. This 

    class must implement the System.Windows.Forms.IFeatureSupport interface or inherit from a class 

    that implements this interface.

  

   featureConstName: The fully qualified name of the feature to look for.

   Returns: A System.Version with the version number of the specified feature available on the system; or 

    null if the feature is not installed.
  """
  pass
 @staticmethod
 def IsPresent(*__args):
  """
  IsPresent(self: FeatureSupport,feature: object) -> bool

  

   Determines whether any version of the specified feature is installed in the system.

  

   feature: The feature to look for.

   Returns: true if the feature is present; otherwise,false.

  IsPresent(self: FeatureSupport,feature: object,minimumVersion: Version) -> bool

  

   Determines whether the specified or newer version of the specified feature is installed in the 

    system.

  

  

   feature: The feature to look for.

   minimumVersion: A System.Version representing the minimum version number of the feature to look for.

   Returns: true if the feature is present and its version number is greater than or equal to the specified 

    minimum version number; false if the feature is not installed or its version number is below the 

    specified minimum number.

  

  IsPresent(featureClassName: str,featureConstName: str) -> bool

  

   Determines whether any version of the specified feature is installed in the system. This method 

    is static.

  

  

   featureClassName: The fully qualified name of the class to query for information about the specified feature. This 

    class must implement the System.Windows.Forms.IFeatureSupport interface or inherit from a class 

    that implements this interface.

  

   featureConstName: The fully qualified name of the feature to look for.

   Returns: true if the specified feature is present; false if the specified feature is not present or if 

    the product containing the feature is not installed.

  

  IsPresent(featureClassName: str,featureConstName: str,minimumVersion: Version) -> bool

  

   Determines whether the specified or newer version of the specified feature is installed in the 

    system. This method is static.

  

  

   featureClassName: The fully qualified name of the class to query for information about the specified feature. This 

    class must implement the System.Windows.Forms.IFeatureSupport interface or inherit from a class 

    that implements this interface.

  

   featureConstName: The fully qualified name of the feature to look for.

   minimumVersion: A System.Version representing the minimum version number of the feature.

   Returns: true if the feature is present and its version number is greater than or equal to the specified 

    minimum version number; false if the feature is not installed or its version number is below the 

    specified minimum number.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass



class Animatable(Freezable,ISealable,IAnimatable,IResource):
 """ Abstract class that provides animation support. """
 def ApplyAnimationClock(self,dp,clock,handoffBehavior=None):
  """
  ApplyAnimationClock(self: Animatable,dp: DependencyProperty,clock: AnimationClock,handoffBehavior: HandoffBehavior)

   Applies an System.Windows.Media.Animation.AnimationClock to the specified 

    System.Windows.DependencyProperty. If the property is already animated,the specified 

    System.Windows.Media.Animation.HandoffBehavior is used.

  

  

   dp: The property to animate.

   clock: The clock with which to animate the specified property. If handoffBehavior is 

    System.Windows.Media.Animation.HandoffBehavior.SnapshotAndReplace and clock is null,all 

    animations will be removed from the specified property (but not stopped). If handoffBehavior is 

    System.Windows.Media.Animation.HandoffBehavior.Compose and clock is null,this method has no 

    effect.

  

   handoffBehavior: A value that specifies how the new animation should interact with any current animations already 

    affecting the property value.

  

  ApplyAnimationClock(self: Animatable,dp: DependencyProperty,clock: AnimationClock)

   Applies an System.Windows.Media.Animation.AnimationClock to the specified 

    System.Windows.DependencyProperty. If the property is already animated,the 

    System.Windows.Media.Animation.HandoffBehavior.SnapshotAndReplace handoff behavior is used.

  

  

   dp: The property to animate.

   clock: The clock with which to animate the specified property. If clock is null,all animations will be 

    removed from the specified property (but not stopped).
  """
  pass
 def BeginAnimation(self,dp,animation,handoffBehavior=None):
  """
  BeginAnimation(self: Animatable,dp: DependencyProperty,animation: AnimationTimeline,handoffBehavior: HandoffBehavior)

   Applies an animation to the specified System.Windows.DependencyProperty. The animation is 

    started when the next frame is rendered. If the specified property is already animated,the 

    specified System.Windows.Media.Animation.HandoffBehavior is used.

  

  

   dp: The property to animate.

   animation: The animation used to animate the specified property.If handoffBehavior is 

    System.Windows.Media.Animation.HandoffBehavior.SnapshotAndReplace and the animation's 

    System.Windows.Media.Animation.Timeline.BeginTime is null,any current animations will be 

    removed and the current value of the property will be held. If handoffBehavior is 

    System.Windows.Media.Animation.HandoffBehavior.SnapshotAndReplace and animation is a null 

    reference,all animations will be removed from the property and the property value will revert 

    back to its base value.If handoffBehavior is 

    System.Windows.Media.Animation.HandoffBehavior.Compose,this method will have no effect if the 

    animation or its System.Windows.Media.Animation.Timeline.BeginTime is null.

  

   handoffBehavior: A value that specifies how the new animation should interact with any current animations already 

    affecting the property value.

  

  BeginAnimation(self: Animatable,dp: DependencyProperty,animation: AnimationTimeline)

   Applies an animation to the specified System.Windows.DependencyProperty. The animation is 

    started when the next frame is rendered. If the specified property is already animated,the 

    System.Windows.Media.Animation.HandoffBehavior.SnapshotAndReplace handoff behavior is used.

  

  

   dp: The property to animate.

   animation: The animation used to animate the specified property.If the animation's 

    System.Windows.Media.Animation.Timeline.BeginTime is null,any current animations will be 

    removed and the current value of the property will be held.If animation is null,all animations 

    will be removed from the property and the property value will revert back to its base value.
  """
  pass
 def Clone(self):
  """
  Clone(self: Animatable) -> Animatable

  

   Creates a modifiable clone of this System.Windows.Media.Animation.Animatable,making deep copies 

    of this object's values. When copying this object's dependency properties,this method copies 

    resource references and data bindings (but they might no longer resolve) but not animations or 

    their current values.

  

   Returns: A modifiable clone of this instance. The returned clone is effectively a deep copy of the 

    current object. The clone's System.Windows.Freezable.IsFrozen property is false.
  """
  pass
 def CloneCore(self,*args):
  """
  CloneCore(self: Freezable,sourceFreezable: Freezable)

   Makes the instance a clone (deep copy) of the specified System.Windows.Freezable using base 

    (non-animated) property values.

  

  

   sourceFreezable: The object to clone.
  """
  pass
 def CloneCurrentValueCore(self,*args):
  """
  CloneCurrentValueCore(self: Freezable,sourceFreezable: Freezable)

   Makes the instance a modifiable clone (deep copy) of the specified System.Windows.Freezable 

    using current property values.

  

  

   sourceFreezable: The System.Windows.Freezable to be cloned.
  """
  pass
 def CreateInstance(self,*args):
  """
  CreateInstance(self: Freezable) -> Freezable

  

   Initializes a new instance of the System.Windows.Freezable class.

   Returns: The new instance.
  """
  pass
 def CreateInstanceCore(self,*args):
  """
  CreateInstanceCore(self: Freezable) -> Freezable

  

   When implemented in a derived class,creates a new instance of the System.Windows.Freezable 

    derived class.

  

   Returns: The new instance.
  """
  pass
 def FreezeCore(self,*args):
  """
  FreezeCore(self: Animatable,isChecking: bool) -> bool

  

   Makes this System.Windows.Media.Animation.Animatable object unmodifiable or determines whether 

    it can be made unmodifiable.

  

  

   isChecking: true if this method should simply determine whether this instance can be frozen. false if this 

    instance should actually freeze itself when this method is called.

  

   Returns: If isChecking is true,this method returns true if this 

    System.Windows.Media.Animation.Animatable can be made unmodifiable,or false if it cannot be 

    made unmodifiable. If isChecking is false,this method returns true if the if this 

    System.Windows.Media.Animation.Animatable is now unmodifiable,or false if it cannot be made 

    unmodifiable,with the side effect of having begun to change the frozen status of this object.
  """
  pass
 def GetAnimationBaseValue(self,dp):
  """
  GetAnimationBaseValue(self: Animatable,dp: DependencyProperty) -> object

  

   Returns the non-animated value of the specified System.Windows.DependencyProperty.

  

   dp: Identifies the property whose base (non-animated) value should be retrieved.

   Returns: The value that would be returned if the specified property were not animated.
  """
  pass
 def GetAsFrozenCore(self,*args):
  """
  GetAsFrozenCore(self: Freezable,sourceFreezable: Freezable)

   Makes the instance a frozen clone of the specified System.Windows.Freezable using base 

    (non-animated) property values.

  

  

   sourceFreezable: The instance to copy.
  """
  pass
 def GetCurrentValueAsFrozenCore(self,*args):
  """
  GetCurrentValueAsFrozenCore(self: Freezable,sourceFreezable: Freezable)

   Makes the current instance a frozen clone of the specified System.Windows.Freezable. If the 

    object has animated dependency properties,their current animated values are copied.

  

  

   sourceFreezable: The System.Windows.Freezable to copy and freeze.
  """
  pass
 def OnChanged(self,*args):
  """
  OnChanged(self: Freezable)

   Called when the current System.Windows.Freezable object is modified.
  """
  pass
 def OnFreezablePropertyChanged(self,*args):
  """
  OnFreezablePropertyChanged(self: Freezable,oldValue: DependencyObject,newValue: DependencyObject,property: DependencyProperty)

   This member supports the Windows Presentation Foundation (WPF) infrastructure and is not 

    intended to be used directly from your code.

  

  

   oldValue: The previous value of the data member.

   newValue: The current value of the data member.

   property: The property that changed.

  OnFreezablePropertyChanged(self: Freezable,oldValue: DependencyObject,newValue: DependencyObject)

   Ensures that appropriate context pointers are established for a 

    System.Windows.DependencyObjectType data member that has just been set.

  

  

   oldValue: The previous value of the data member.

   newValue: The current value of the data member.
  """
  pass
 def OnPropertyChanged(self,*args):
  """
  OnPropertyChanged(self: Freezable,e: DependencyPropertyChangedEventArgs)

   Overrides the System.Windows.DependencyObject implementation of 

    System.Windows.DependencyObject.OnPropertyChanged(System.Windows.DependencyPropertyChangedEventAr

    gs) to also invoke any System.Windows.Freezable.Changed handlers in response to a changing 

    dependency property of type System.Windows.Freezable.

  

  

   e: Event data that contains information about which property changed,and its old and new values.
  """
  pass
 def ReadPreamble(self,*args):
  """
  ReadPreamble(self: Freezable)

   Ensures that the System.Windows.Freezable is being accessed from a valid thread. Inheritors of 

    System.Windows.Freezable must call this method at the beginning of any API that reads data 

    members that are not dependency properties.
  """
  pass
 def ShouldSerializeProperty(self,*args):
  """
  ShouldSerializeProperty(self: DependencyObject,dp: DependencyProperty) -> bool

  

   Returns a value that indicates whether serialization processes should serialize the value for 

    the provided dependency property.

  

  

   dp: The identifier for the dependency property that should be serialized.

   Returns: true if the dependency property that is supplied should be value-serialized; otherwise,false.
  """
  pass
 @staticmethod
 def ShouldSerializeStoredWeakReference(target):
  """
  ShouldSerializeStoredWeakReference(target: DependencyObject) -> bool

  

   Specifies whether a dependency object should be serialized.

  

   target: Represents an object that participates in the dependency property system.

   Returns: true to serialize target; otherwise,false. The default is false.
  """
  pass
 def WritePostscript(self,*args):
  """
  WritePostscript(self: Freezable)

   Raises the System.Windows.Freezable.Changed event for the System.Windows.Freezable and invokes 

    its System.Windows.Freezable.OnChanged method. Classes that derive from System.Windows.Freezable 

    should call this method at the end of any API that modifies class members that are not stored as 

    dependency properties.
  """
  pass
 def WritePreamble(self,*args):
  """
  WritePreamble(self: Freezable)

   Verifies that the System.Windows.Freezable is not frozen and that it is being accessed from a 

    valid threading context. System.Windows.Freezable inheritors should call this method at the 

    beginning of any API that writes to data members that are not dependency properties.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 HasAnimatedProperties=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether one or more System.Windows.Media.Animation.AnimationClock objects is associated with any of this object's dependency properties.



Get: HasAnimatedProperties(self: Animatable) -> bool



"""





class InitializingNewItemEventArgs(EventArgs):
 """
 Provides data for the System.Windows.Controls.DataGrid.InitializingNewItem event.

 

 InitializingNewItemEventArgs(newItem: object)
 """
 @staticmethod
 def __new__(self,newItem):
  """ __new__(cls: type,newItem: object) """
  pass
 NewItem=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the new item added to the System.Windows.Controls.DataGrid.



Get: NewItem(self: InitializingNewItemEventArgs) -> object



"""





""" Standard IO Dialogs

Original code by github.com/pyrevitlabs/pyRevit

"""  #

from rpw.ui.forms.resources import *

def select_folder():
    """
    Selects a Folder Path using the standard OS Dialog.
    Uses Forms.FolderBrowserDialog(). For more information see:
    https://msdn.microsoft.com/en-us/library/system.windows.forms.openfiledialog.

    >>> from rpw.ui.forms import select_folder
    >>> folderpath = select_folder()
    'C:\\folder\\path'
    """

    form = Forms.FolderBrowserDialog()
    if form.ShowDialog() == Forms.DialogResult.OK:
        return form.SelectedPath


def select_file(extensions='All Files (*.*)|*.*',
                title="Select File",
                multiple=False,
                restore_directory=True):
    """
    Selects a File Path using the standard OS Dialog.
    Uses Forms.OpenFileDialog
    https://msdn.microsoft.com/en-us/library/system.windows.forms.filedialog.filter

    >>> from rpw.ui.forms import select_file
    >>> filepath = select_file('Revit Model (*.rvt)|*.rvt')
    'C:\\folder\\file.rvt'

    Args:
        extensions (str, optional): File Extensions Filtering options. Default is All Files (*.*)|*.*
        title (str, optional): File Extensions Filtering options
        multiple (bool): Allow selection of multiple files. Default is `False`
        restore_directory (bool): Restores the directory to the previously selected directory before closing

    Returns:
        filepath (list, string): filepath string if ``multiple=False`` otherwise list of filepath strings

    """
    form = Forms.OpenFileDialog()
    form.Filter = extensions
    form.Title = title
    form.Multiselect = multiple
    form.RestoreDirectory = restore_directory
    if form.ShowDialog() == Forms.DialogResult.OK:
        return form.FileName if not multiple else list(form.FileNames)

# Tests
if __name__ == '__main__':
    # print(select_folder())
    # print(select_file('Python Files|*.py'))
    print(select_file('Python Files|*.py', multiple=False))
    print(select_file('Python Files|*.py', multiple=True))
